commands

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CGCommand

type CGCommand struct {
	VideoChannel int
	Layer        *int // defaults to 9999
	CgLayer      *int // optional, only used for layer-specific commands
}

type CommandBye

type CommandBye struct{}

func (CommandBye) String

func (c CommandBye) String() string

type CommandKill

type CommandKill struct{}

func (CommandKill) String

func (c CommandKill) String() string

type CommandRestart

type CommandRestart struct{}

func (CommandRestart) String

func (c CommandRestart) String() string

type DirectCommandLogLevel

type DirectCommandLogLevel struct {
	Level types.LogLevel
}

func (DirectCommandLogLevel) String

func (c DirectCommandLogLevel) String() string

type DirectCommandPing

type DirectCommandPing struct {
	Token *string
}

func (DirectCommandPing) String

func (c DirectCommandPing) String() string

type LayerAdd

type LayerAdd struct {
	LayerCommand

	ConsumerIdx  *int
	ConsumerName string // TODO: Make this an enum of possible consumer types
	Params       *[]string
}

func (LayerAdd) String

func (c LayerAdd) String() string

type LayerCall

type LayerCall struct {
	LayerCommand

	Params []string
}

func (LayerCall) String

func (c LayerCall) String() string

type LayerClear

type LayerClear struct {
	LayerCommand
}

func (LayerClear) String

func (c LayerClear) String() string

type LayerCommand

type LayerCommand struct {
	VideoChannel int
	Layer        *int // Layer is optional for channel-level commands
}

type LayerInfo

type LayerInfo struct {
	LayerCommand
}

func (LayerInfo) String

func (c LayerInfo) String() string

type LayerInfoDelay

type LayerInfoDelay struct {
	LayerCommand
}

func (LayerInfoDelay) String

func (c LayerInfoDelay) String() string

type LayerLoad

type LayerLoad struct {
	LayerCommand

	Clip string

	Parameters *[]string
}

func (LayerLoad) String

func (c LayerLoad) String() string

type LayerLock

type LayerLock struct {
	LayerCommand

	Action     types.LockAction
	Passphrase *string
}

func (LayerLock) String

func (c LayerLock) String() string

type LayerPause

type LayerPause struct {
	LayerCommand
}

func (LayerPause) String

func (c LayerPause) String() string

type LayerPlay

type LayerPlay struct {
	LayerCommand

	Clip       *string
	Parameters *[]string
}

func (LayerPlay) String

func (c LayerPlay) String() string

type LayerPrint

type LayerPrint struct {
	LayerCommand
}

func (LayerPrint) String

func (c LayerPrint) String() string

type LayerRemove

type LayerRemove struct {
	LayerCommand

	ConsumerIdx *int
	Parameters  *[]string
}

func (LayerRemove) String

func (c LayerRemove) String() string

type LayerResume

type LayerResume struct {
	LayerCommand
}

func (LayerResume) String

func (c LayerResume) String() string

type LayerSet

type LayerSet struct {
	LayerCommand

	VariableName types.SetVariable
	Value        string
}

func (LayerSet) String

func (c LayerSet) String() string

type LayerStop

type LayerStop struct {
	LayerCommand
}

func (LayerStop) String

func (c LayerStop) String() string

type LayerSwap

type LayerSwap struct {
	LayerCommand

	VideoChannel2 int
	Layer2        *int

	Transform bool // either nil or "TRANSFORMS"
}

func (LayerSwap) String

func (c LayerSwap) String() string

type MixerAnchor

type MixerAnchor struct {
	MixerCommand

	X *float32 // X: The x anchor point, 0 = left edge of layer, 0.5 = middle of layer, 1.0 = right edge of layer. Higher and lower values allowed.
	Y *float32 // Y: The y anchor point, 0 = top edge of layer, 0.5 = middle of layer, 1.0 = bottom edge of layer. Higher and lower values allowed.

	Duration *int
	Tween    *types.TweenType
}

func (MixerAnchor) String

func (c MixerAnchor) String() string

type MixerBlend

type MixerBlend struct {
	MixerCommand

	BlendMode *types.BlendMode
}

func (MixerBlend) String

func (c MixerBlend) String() string

type MixerBrightness

type MixerBrightness struct {
	MixerCommand

	Brightness *float32

	Duration *int
	Tween    *types.TweenType
}

func (MixerBrightness) String

func (c MixerBrightness) String() string

type MixerChroma

type MixerChroma struct {
	MixerCommand

	Enable *bool

	TargetHue               *float32
	HueWidth                *float32
	MinSaturation           *float32
	MinBrightness           *float32
	Softness                *float32
	SpillSuppress           *float32
	SpillSuppressSaturation *float32
	ShowMask                *bool

	FadeDuration *int
	Tween        *types.TweenType
}

func (MixerChroma) String

func (c MixerChroma) String() string

type MixerClear

type MixerClear struct {
	MixerCommand
}

func (MixerClear) String

func (c MixerClear) String() string

type MixerClip

type MixerClip struct {
	MixerCommand

	X      *float32 // X: The new x position, 0 = left edge of monitor, 0.5 = middle of monitor, 1.0 = right edge of monitor. Higher and lower values allowed.
	Y      *float32 // Y: The new y position, 0 = top edge of monitor, 0.5 = middle of monitor, 1.0 = bottom edge of monitor. Higher and lower values allowed.
	Width  *float32 // Width: The new width, 1 = 1x the screen width, 0.5 = half the screen width. Higher and lower values allowed. Negative values flips the layer.
	Height *float32 // Height: The new height, 1 = 1x the screen height, 0.5 = half the screen height. Higher and lower values allowed. Negative values flips the layer.

	Duration *int
	Tween    *types.TweenType
}

func (MixerClip) String

func (c MixerClip) String() string

type MixerCommand

type MixerCommand struct {
	VideoChannel int
	Layer        *int // defaults to 9999
}

type MixerCommit

type MixerCommit struct {
	MixerCommand // channel only command, Layer is nil
}

func (MixerCommit) String

func (c MixerCommit) String() string

type MixerContrast

type MixerContrast struct {
	MixerCommand

	Contrast *float32

	Duration *int
	Tween    *types.TweenType
}

func (MixerContrast) String

func (c MixerContrast) String() string

type MixerCrop

type MixerCrop struct {
	MixerCommand

	LeftEdge   *float32 // LeftEdge: A value between 0 and 1 defining how far into the layer to crop from the left edge.
	TopEdge    *float32 // TopEdge: A value between 0 and 1 defining how far into the layer to crop from the top edge.
	RightEdge  *float32 // RightEdge: A value between 0 and 1 defining how far into the layer to crop from the right edge.
	BottomEdge *float32 // BottomEdge: A value between 0 and 1 defining how far into the layer to crop from the bottom edge.

	Duration *int
	Tween    *types.TweenType
}

func (MixerCrop) String

func (c MixerCrop) String() string

type MixerFill

type MixerFill struct {
	MixerCommand

	X      *float32 // X the new x position, 0 = left edge of monitor, 0.5 = middle of monitor, 1.0 = right edge of monitor. Higher and lower values allowed.
	Y      *float32 // Y the new y position, 0 = top edge of monitor, 0.5 = middle of monitor, 1.0 = bottom edge of monitor. Higher and lower values allowed.
	XScale *float32 // XScale the new x scale, 1.0 = original size, 0.5 = half size, 2.0 = double size. Higher and lower values allowed.
	YScale *float32 // YScale the new y scale, 1.0 = original size, 0.5 = half size, 2.0 = double size. Higher and lower values allowed.

	Duration *int
	Tween    *types.TweenType
}

func (MixerFill) String

func (c MixerFill) String() string

type MixerGrid

type MixerGrid struct {
	MixerCommand // channel only command, Layer is nil

	Resolution *int

	Duration *int
	Tween    *types.TweenType
}

func (MixerGrid) String

func (c MixerGrid) String() string

type MixerInvert

type MixerInvert struct {
	MixerCommand

	Invert *bool
}

func (MixerInvert) String

func (c MixerInvert) String() string

type MixerKeyer

type MixerKeyer struct {
	MixerCommand

	Show bool
}

func (MixerKeyer) String

func (c MixerKeyer) String() string

type MixerLevels

type MixerLevels struct {
	MixerCommand

	MinInput  *float32 // MinInput and MaxInput define the input range (between 0 and 1) to accept RGB values within.
	MaxInput  *float32
	Gamma     *float32 // Gamma adjusts the gamma of the image.
	MinOutput *float32 // MinOutput and MaxOutput define the output range (between 0 and 1) to scale the accepted input RGB values to.
	MaxOutput *float32

	Duration *int
	Tween    *types.TweenType
}

func (MixerLevels) String

func (c MixerLevels) String() string

type MixerMasterVolume

type MixerMasterVolume struct {
	MixerCommand // channel only command, Layer is nil

	Volume *float32 // Volume: The new volume, 1.0 = original volume, 0.5 = half volume, 2.0 = double volume. Higher and lower values allowed.
}

func (MixerMasterVolume) String

func (c MixerMasterVolume) String() string

type MixerMipMap

type MixerMipMap struct {
	MixerCommand

	Enable *bool
}

func (MixerMipMap) String

func (c MixerMipMap) String() string

type MixerOpacity

type MixerOpacity struct {
	MixerCommand

	Opacity *float32

	Duration *int
	Tween    *types.TweenType
}

func (MixerOpacity) String

func (c MixerOpacity) String() string

type MixerPerspective

type MixerPerspective struct {
	MixerCommand

	TopLeftX *float32 // TopLeftX: Defines the x coordinate of the top left corner.
	TopLeftY *float32 // TopLeftY: Defines the y coordinate of the top left corner.

	TopRightX *float32 // TopRightX: Defines the x coordinate of the top right corner.
	TopRightY *float32 // TopRightY: Defines the y coordinate of the top right corner.

	BottomLeftX *float32 // BottomLeftX: Defines the x coordinate of the bottom left corner.
	BottomLeftY *float32 // BottomLeftY: Defines the y coordinate of the bottom left corner.

	BottomRightX *float32 // BottomRightX: Defines the x coordinate of the bottom right corner.
	BottomRightY *float32 // BottomRightY: Defines the y coordinate of the bottom right corner.

	Duration *int
	Tween    *types.TweenType
}

func (MixerPerspective) String

func (c MixerPerspective) String() string

type MixerRotation

type MixerRotation struct {
	MixerCommand

	Angle *float32 // Angle: The absolute rotation angle in degrees going from 0 to 360.

	Duration *int
	Tween    *types.TweenType
}

func (MixerRotation) String

func (c MixerRotation) String() string

type MixerSaturation

type MixerSaturation struct {
	MixerCommand

	Saturation *float32

	Duration *int
	Tween    *types.TweenType
}

func (MixerSaturation) String

func (c MixerSaturation) String() string

type MixerStraightAlphaOutput

type MixerStraightAlphaOutput struct {
	MixerCommand // channel only command, Layer is nil

	Enable *bool
}

func (MixerStraightAlphaOutput) String

func (c MixerStraightAlphaOutput) String() string

type MixerVolume

type MixerVolume struct {
	MixerCommand

	Volume *float32 // Volume: The new volume, 1.0 = original volume, 0.5 = half volume, 2.0 = double volume. Higher and lower values allowed.

	Duration *int
	Tween    *types.TweenType
}

func (MixerVolume) String

func (c MixerVolume) String() string

type QueryCINF

type QueryCINF struct {
	Filename string
}

func (QueryCINF) String

func (c QueryCINF) String() string

type QueryCLS

type QueryCLS struct {
	Directory *string
}

func (QueryCLS) String

func (c QueryCLS) String() string

type QueryDiag

type QueryDiag struct{}

func (QueryDiag) String

func (c QueryDiag) String() string

type QueryFLS

type QueryFLS struct{}

func (QueryFLS) String

func (c QueryFLS) String() string

type QueryGLGC

type QueryGLGC struct{}

func (QueryGLGC) String

func (c QueryGLGC) String() string

type QueryGLInfo

type QueryGLInfo struct{}

func (QueryGLInfo) String

func (c QueryGLInfo) String() string

type QueryHelp

type QueryHelp struct {
	Command *string
}

func (QueryHelp) String

func (c QueryHelp) String() string

type QueryHelpConsumer

type QueryHelpConsumer struct {
	Consumer *string
}

func (QueryHelpConsumer) String

func (c QueryHelpConsumer) String() string

type QueryHelpProducer

type QueryHelpProducer struct {
	Producer *string
}

func (QueryHelpProducer) String

func (c QueryHelpProducer) String() string

type QueryInfo

type QueryInfo struct {
	Component types.InfoComponent
}

func (QueryInfo) String

func (c QueryInfo) String() string

type QueryInfoTemplate

type QueryInfoTemplate struct {
	Template string
}

func (QueryInfoTemplate) String

func (c QueryInfoTemplate) String() string

type QueryTLS

type QueryTLS struct {
	Directory *string
}

func (QueryTLS) String

func (c QueryTLS) String() string

type QueryVersion

type QueryVersion struct {
	Component types.VersionInfo
}

func (QueryVersion) String

func (c QueryVersion) String() string

type TemplateCGAdd

type TemplateCGAdd struct {
	CGCommand

	Template string

	PlayOnLoad bool
	Data       *string // JSON or XML inline string
}

func (TemplateCGAdd) String

func (c TemplateCGAdd) String() string

type TemplateCGClear

type TemplateCGClear struct {
	CGCommand
}

func (TemplateCGClear) String

func (c TemplateCGClear) String() string

type TemplateCGInfo

type TemplateCGInfo struct {
	CGCommand
}

func (TemplateCGInfo) String

func (c TemplateCGInfo) String() string

type TemplateCGInvoke

type TemplateCGInvoke struct {
	CGCommand

	Method string
}

func (TemplateCGInvoke) String

func (c TemplateCGInvoke) String() string

type TemplateCGNext

type TemplateCGNext struct {
	CGCommand
}

func (TemplateCGNext) String

func (c TemplateCGNext) String() string

type TemplateCGPlay

type TemplateCGPlay struct {
	CGCommand
}

func (TemplateCGPlay) String

func (c TemplateCGPlay) String() string

type TemplateCGRemove

type TemplateCGRemove struct {
	CGCommand
}

func (TemplateCGRemove) String

func (c TemplateCGRemove) String() string

type TemplateCGStop

type TemplateCGStop struct {
	CGCommand
}

func (TemplateCGStop) String

func (c TemplateCGStop) String() string

type TemplateCGUpdate

type TemplateCGUpdate struct {
	CGCommand

	Data string // JSON or XML inline string
}

func (TemplateCGUpdate) String

func (c TemplateCGUpdate) String() string

Jump to